@@ -1,17 +1,17 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2023, by Samuel Williams.
+# Copyright, 2023-2024, by Samuel Williams.
 
-require 'bake/modernize'
-require 'markly'
+require "bake/modernize"
+require "markly"
 
 def contributing
 	if conduct_path = Dir["conduct.md"]
 		FileUtils.rm_f(conduct_path)
 	end
 	
-	update_contributing(File.join(Dir.pwd, 'readme.md'))
+	update_contributing(File.join(Dir.pwd, "readme.md"))
 end
 
 private
@@ -29,11 +29,11 @@ We welcome contributions to this project.
 
 ### Developer Certificate of Origin
 
-This project uses the [Developer Certificate of Origin](https://developercertificate.org/). All contributors to this project must agree to this document to have their contributions accepted.
+In order to protect users of this project, we require all contributors to comply with the [Developer Certificate of Origin](https://developercertificate.org/). This ensures that all contributions are properly licensed and attributed.
 
-### Contributor Covenant
+### Community Guidelines
 
-This project is governed by the [Contributor Covenant](https://www.contributor-covenant.org/). All contributors and participants agree to abide by its terms.
+This project is best served by a collaborative and respectful environment. Treat each other professionally, respect differing viewpoints, and engage constructively. Harassment, discrimination, or harmful behavior is not tolerated. Communicate clearly, listen actively, and support one another. If any issues arise, please inform the project maintainers.
 EOF
 
 def update_contributing(readme_path)
