@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2021-2022, by Samuel Williams.
+# Copyright, 2021-2024, by Samuel Williams.
 
-require 'bake/modernize'
+require "bake/modernize"
 
 def signing
 	update(root: Dir.pwd)
